@@ -2,7 +2,7 @@ from django import forms
 from django.conf import settings
 from django.db.models import get_model
 from django.forms.util import ErrorList
-from django.utils.translation import ugettext as _
+from django.utils.translation import ugettext_lazy as _
 
 from profiles.models import Profile
 
@@ -39,6 +39,7 @@ class UserChangeForm(forms.ModelForm):
             user.set_password(self.cleaned_data['password1'])
         if commit:
             user.save()
+            self.save_m2m()
         return user
 
 
